@@ -1,14 +1,11 @@
-
-############################### Fonction hlme ###################################
-
 hlme <-
-function(fixed,mixture,random,subject,classmb,ng=1,idiag=FALSE,nwg=FALSE,data,B,convB=0.0001,convL=0.0001,convG=0.0001,prior,Maxiter=100){
-cat("Be patient. The program is running ... \n")
+function(fixed,mixture,random,subject,classmb,ng=1,idiag=FALSE,nwg=FALSE,data,B,convB=0.0001,convL=0.0001,convG=0.0001,prior,maxiter=500){
 
 cl <- match.call()
 args <- as.list(match.call(hlme))[-1]
 
-nom.subject <- as.character(args$subject)
+#nom.subject <- as.character(args$subject)
+nom.subject <- as.character(subject)
 #### INCLUSION PRIOR
 nom.prior <- as.character(args$prior)
 ####
@@ -202,7 +199,7 @@ NVC<-(kk*(kk+1))/2}
 NW<-nwg0*(ng0-1)
 if(NW>0) b[(NPROB+NEF+NVC+1):(NPROB+NEF+NVC+NW)]<-1
 NPM<-NPROB+NEF+NVC+NW+1
-V <- rep(0,NPM*(NPM+3)/2)
+V <- rep(0,NPM*(NPM+1)/2)
 } 
 
 
@@ -224,7 +221,7 @@ pred_ss_g2 <- rep(0,nobs0)
 
 V2 <- rep(0,NPM2*(NPM2+1)/2)
 best <- rep(0,NPM2)
-init <- .Fortran("hetmixlin",as.double(Y0),as.double(X0),as.integer(prior2),as.integer(idprob2),as.integer(idea2),as.integer(idg2),as.integer(ns0),as.integer(ng2),as.integer(nv0),as.integer(nobs0),as.integer(nea0),as.integer(nmes0),as.integer(idiag0),as.integer(nwg2),npm=as.integer(NPM2),best=as.double(b1),V=as.double(V2),loglik=as.double(loglik),niter=as.integer(ni),conv=as.integer(istop),gconv=as.double(gconv),ppi2=as.double(ppi2),resid_m=as.double(resid_m),resid_ss=as.double(resid_ss),pred_m_g=as.double(pred_m_g2),pred_ss_g=as.double(pred_ss_g2),predRE=as.double(predRE),as.double(convB),as.double(convL),as.double(convG),as.integer(Maxiter),PACKAGE="lcmm")
+init <- .Fortran("hetmixlin",as.double(Y0),as.double(X0),as.integer(prior2),as.integer(idprob2),as.integer(idea2),as.integer(idg2),as.integer(ns0),as.integer(ng2),as.integer(nv0),as.integer(nobs0),as.integer(nea0),as.integer(nmes0),as.integer(idiag0),as.integer(nwg2),npm=as.integer(NPM2),best=as.double(b1),V=as.double(V2),loglik=as.double(loglik),niter=as.integer(ni),conv=as.integer(istop),gconv=as.double(gconv),ppi2=as.double(ppi2),resid_m=as.double(resid_m),resid_ss=as.double(resid_ss),pred_m_g=as.double(pred_m_g2),pred_ss_g=as.double(pred_ss_g2),predRE=as.double(predRE),as.double(convB),as.double(convL),as.double(convG),as.integer(maxiter),PACKAGE="lcmm")
 
 k <- NPROB
 l <- 0
@@ -292,9 +289,12 @@ idea <- as.integer(idea0)
 nv <- as.integer(nv0)
 
 
+cat("Be patient, hlme program is running ... \n")
+
+
 ################ Sortie ###########################
 
-out <- .Fortran("hetmixlin",as.double(Y0),as.double(X0),as.integer(prior0),as.integer(idprob0),as.integer(idea0),as.integer(idg0),as.integer(ns0),as.integer(ng0),as.integer(nv0),as.integer(nobs0),as.integer(nea0),as.integer(nmes0),as.integer(idiag0),as.integer(nwg0),as.integer(NPM),best=as.double(b),V=as.double(V),loglik=as.double(loglik),niter=as.integer(ni),conv=as.integer(istop),gconv=as.double(gconv),ppi2=as.double(ppi0),resid_m=as.double(resid_m),resid_ss=as.double(resid_ss),pred_m_g=as.double(pred_m_g),pred_ss_g=as.double(pred_ss_g),predRE=as.double(predRE),as.double(convB),as.double(convL),as.double(convG),as.integer(Maxiter),PACKAGE="lcmm")
+out <- .Fortran("hetmixlin",as.double(Y0),as.double(X0),as.integer(prior0),as.integer(idprob0),as.integer(idea0),as.integer(idg0),as.integer(ns0),as.integer(ng0),as.integer(nv0),as.integer(nobs0),as.integer(nea0),as.integer(nmes0),as.integer(idiag0),as.integer(nwg0),as.integer(NPM),best=as.double(b),V=as.double(V),loglik=as.double(loglik),niter=as.integer(ni),conv=as.integer(istop),gconv=as.double(gconv),ppi2=as.double(ppi0),resid_m=as.double(resid_m),resid_ss=as.double(resid_ss),pred_m_g=as.double(pred_m_g),pred_ss_g=as.double(pred_ss_g),predRE=as.double(predRE),as.double(convB),as.double(convL),as.double(convG),as.integer(maxiter),PACKAGE="lcmm")
 
 
 ### Creation du vecteur cholesky
@@ -341,7 +341,6 @@ names(out$best)<-names(b)
 btest <- out$best[1:length(inddepvar.fixed.nom)]
 names(btest) <-inddepvar.fixed.nom
 res <-list(ns=ns0,ng=ng0,idea0=idea0,idprob0=idprob0,idg0=idg0,loglik=out$loglik,best=out$best,V=out$V,gconv=out$gconv,conv=out$conv,call=cl,niter=out$niter,dataset=args$data,N=N,name.mat.cov=inddepvar.random.nom,idiag=idiag0,pred=pred,pprob=ppi,predRE=predRE,Xnames=nom.X0,cholesky=Cholesky)
-class(res) <-"hlme"
-#class(res) <-"lcmm"  
+class(res) <-c("hlme")  
 res
 }
