@@ -3,9 +3,6 @@ function(object,...){
 x <- object
 if (!inherits(x, "hlme")) stop("use only with \"hlme\" objects")
 
-#cat("\nCall:\n", deparse(x$call), "\n\n", sep = "")
-
-
 cat("Heterogenous linear mixed model", "\n")
 cat("     fitted by maximum likelihood method", "\n")
 
@@ -25,7 +22,9 @@ cat("Iteration process:", "\n")
 
 if(x$conv==1) cat("Convergence criteria satisfied")
 if(x$conv==2) cat("Maximum number of iteration reached without convergence")
-if(x$conv==4|x$conv==5) stop("Program stopped, please check the data and model specification")
+if(x$conv==4|x$conv==12) {
+cat("The program stopped abnormally. No results can be displayed.\n")
+}else{
 
 cat(" \n")
 cat("     Number of iterations: ", x$niter, "\n")
@@ -57,12 +56,16 @@ id <- 1:NPM
 indice <- rep(id*(id+1)/2)
 se <-sqrt(x$V[indice])
 se[(NPROB+NEF+1):(NPROB+NEF+NVC)]<-1
-}
-
-
 wald <- x$best/se
 pwald <- 1-pchisq(wald**2,1)
 coef <- x$best
+}else{
+se <- NA
+wald <- NA
+pwald <- NA
+coef <- x$best
+}
+
 
 
 if(NPROB>0){
@@ -111,8 +114,6 @@ Mat.cov[upper.tri(Mat.cov)] <- NA
 
 print(Mat.cov,na.print="")
 cat("\n")
-
-
 }
 }
 
@@ -127,8 +128,7 @@ colnames(std) <-c("coef","se")
 }
 print(std)
 cat("\n")
-
-
-
+}
 }
 
+
